@@ -9,18 +9,21 @@ AbstractGroupListModel::AbstractGroupListModel(QObject *parent) :
     ,m_cache(new ThumbnailCache)
   #endif
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[VideoCountRole] = "videoCount";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[VideoCountRole] = "videoCount";
 #ifndef QML_USER_INTERFACE
-    roles[ThumbnailRole] = "thumbnail";
+    m_roleNames[ThumbnailRole] = "thumbnail";
 #endif
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
-    roles[DescriptionRole] = "description";
-    this->setRoleNames(roles);
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[DescriptionRole] = "description";
+    m_roleNames[ServiceRole] = "service";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
+
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -34,6 +37,12 @@ AbstractGroupListModel::~AbstractGroupListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> AbstractGroupListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void AbstractGroupListModel::clear() {
     this->beginResetModel();
     m_list.clear();
@@ -66,6 +75,8 @@ QVariant AbstractGroupListModel::data(const QModelIndex &index, int role) const
         return m_list.at(index.row()).data()->thumbnailUrl();
     case DescriptionRole:
         return m_list.at(index.row()).data()->description();
+    case ServiceRole:
+        return m_list.at(index.row()).data()->service();
     default:
         return QVariant();
     }
