@@ -197,6 +197,38 @@ bool AbstractVideoListModel::removeRow(int row, const QModelIndex &parent)
     return false;
 }
 
+void AbstractVideoListModel::selectRow(int row) {
+    if (!m_selectedRows.contains(row)) {
+        m_selectedRows.append(row);
+        emit dataChanged(this->index(row), this->index(row));
+    }
+}
+
+void AbstractVideoListModel::selectRows(const QList<int> &rows) {
+    foreach (int row, rows) {
+        if (!m_selectedRows.contains(row)) {
+            m_selectedRows.append(row);
+        }
+    }
+
+    emit dataChanged(this->index(0), this->index(this->rowCount() - 1));
+}
+
+void AbstractVideoListModel::deselectRow(int row) {
+    if (m_selectedRows.contains(row)) {
+        m_selectedRows.removeOne(row);
+        emit dataChanged(this->index(row), this->index(row));
+    }
+}
+
+void AbstractVideoListModel::deselectRows(const QList<int> &rows) {
+    foreach (int row, rows) {
+        m_selectedRows.removeOne(row);
+    }
+
+    emit dataChanged(this->index(0), this->index(this->rowCount() - 1));
+}
+
 void AbstractVideoListModel::toggleSelected(int row) {
     if (!m_selectedRows.contains(row)) {
         m_selectedRows.append(row);
