@@ -7,13 +7,14 @@
 DailymotionAccountsListModel::DailymotionAccountsListModel(QObject *parent) :
     QSqlTableModel(parent, QSqlDatabase::database())
 {
-    QHash<int, QByteArray> roles;
-    roles[DisplayNameRole] = "displayName";
-    roles[UsernameRole] = "username";
-    roles[AccessTokenRole] = "accessToken";
-    roles[RefreshTokenRole] = "refreshToken";
-    roles[ActiveRole] = "active";
-    this->setRoleNames(roles);
+    m_roleNames[DisplayNameRole] = "displayName";
+    m_roleNames[UsernameRole] = "username";
+    m_roleNames[AccessTokenRole] = "accessToken";
+    m_roleNames[RefreshTokenRole] = "refreshToken";
+    m_roleNames[ActiveRole] = "active";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
     this->setTable("dailymotionAccounts");
     this->setEditStrategy(QSqlTableModel::OnManualSubmit);
     this->select();
@@ -29,6 +30,12 @@ DailymotionAccountsListModel::~DailymotionAccountsListModel() {
     this->clear();
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> DailymotionAccountsListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void DailymotionAccountsListModel::setActiveAccount(int row) {
     this->database().open();
     QSqlField nameField("name", QVariant::String);
