@@ -27,6 +27,9 @@ public:
 public:
     explicit DailymotionUserPlaylistListModel(QObject *parent = 0);
     ~DailymotionUserPlaylistListModel() {}
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
@@ -42,6 +45,9 @@ private slots:
 
 signals:
     void countChanged(int count);
+
+private:
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // DAILYMOTIONUSERPLAYLISTLISTMODEL_H
