@@ -21,6 +21,9 @@ class DailymotionVideoListModel : public AbstractVideoListModel
                READ feed
                WRITE setFeed
                NOTIFY feedChanged)
+    Q_PROPERTY(QString playlistId
+               READ playlistId
+               NOTIFY feedChanged)
     Q_PROPERTY(bool refreshRequired
                READ refreshRequired
                NOTIFY refreshRequiredChanged)
