@@ -1,4 +1,5 @@
 #include "settings.h"
+#include "definitions.h"
 #include <QDir>
 #include <QNetworkProxy>
 #include <QAuthenticator>
@@ -11,12 +12,14 @@
 #include <QDesktopServices>
 #endif
 
-Settings* settingsInstance = 0;
+Settings* Settings::self = 0;
 
 Settings::Settings(QObject *parent) :
     QSettings(QString("cuteTube"), QString("cuteTube"), parent),
     m_autoTransfers(true),
     m_maxConcurrentTransfers(1),
+    m_maxConnectionsPerTransfer(1),
+    m_downloadSubtitles(false),
     m_safeSearch(false),
     m_searchSite(Services::YouTube),
     m_showSearchSite(true),
@@ -30,6 +33,7 @@ Settings::Settings(QObject *parent) :
     m_showSearchType(true),
     m_languageFilter("all"),
     m_showSearchLanguage(false),
+    m_subtitlesLanguage("en"),
   #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     m_theme("dark"),
     m_activeColor("#0881cb"),
@@ -45,6 +49,9 @@ Settings::Settings(QObject *parent) :
     m_mediaplayer("mediaplayer"),
   #endif
     m_orientation(ScreenOrientation::Automatic),
+  #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    m_fullscreen(false),
+  #endif
     m_monitorClipboard(false),
     m_proxyType(NetworkProxyType::HttpProxy),
     m_proxyPort(80),
@@ -61,8 +68,8 @@ Settings::Settings(QObject *parent) :
   ,m_checkUpdate(false)
   #endif
 {
-    if (!settingsInstance) {
-        settingsInstance = this;
+    if (!self) {
+        self = this;
     }
 }
 
@@ -71,15 +78,15 @@ Settings::~Settings() {
 }
 
 Settings* Settings::instance() {
-    return settingsInstance;
+    return !self ? new Settings : self;
 }
 
 void Settings::restoreSettings() {
     this->beginGroup("Media");
     this->setYouTubePlaybackFormats(this->value("youtubePlaybackFormats", QVariantList() << Videos::MobileLQ << Videos::MobileNormal << Videos::LQ).toList());
     this->setYouTubeDownloadFormats(this->value("youtubeDownloadFormats", QVariantList() << Videos::MobileLQ << Videos::MobileNormal << Videos::LQ).toList());
-    this->setDailymotionPlaybackFormats(this->value("dailymotionPlaybackFormats", QVariantList() << Videos::Normal).toList());
-    this->setDailymotionDownloadFormats(this->value("dailymotionDownloadFormats", QVariantList() << Videos::Normal).toList());
+    this->setDailymotionPlaybackFormats(this->value("dailymotionPlaybackFormats", QVariantList() << Videos::LQ << Videos::Normal).toList());
+    this->setDailymotionDownloadFormats(this->value("dailymotionDownloadFormats", QVariantList() << Videos::LQ << Videos::Normal).toList());
 #ifdef Q_WS_MAEMO_5
     this->setVimeoPlaybackFormats(this->value("vimeoPlaybackFormats", QVariantList() << Videos::LQ).toList());
     this->setVimeoDownloadFormats(this->value("vimeoDownloadFormats", QVariantList() << Videos::LQ).toList());
@@ -108,11 +115,14 @@ void Settings::restoreSettings() {
     this->setMediaPlayerCommand(this->value("mediaPlayerCommand", QString()).toString());
 #endif
     this->setLanguageFilter(this->value("languageFilter", QString("all")).toString());
+    this->setSubtitlesLanguage(this->value("subtitlesLanguage", QString("en")).toString());
     this->endGroup();
 
     this->beginGroup("Transfers");
     this->setStartTransfersAutomatically(this->value("startTransfersAutomatically", true).toBool());
     this->setMaximumConcurrentTransfers(this->value("maximumConcurrentTransfers", 1).toInt());
+    this->setMaximumConnectionsPerTransfer(this->value("maximumConnectionsPerTransfer", 1).toInt());
+    this->setDownloadSubtitles(this->value("downloadSubtitles", false).toBool());
 #if (defined (Q_WS_MAEMO_5)) || (defined (MEEGO_EDITION_HARMATTAN))
     this->setDownloadPath(this->value("downloadPath", QString("/home/user/MyDocs/cuteTube/")).toString());
 #elif defined (SYMBIAN_OS)
@@ -160,6 +170,9 @@ void Settings::restoreSettings() {
     this->beginGroup("System");
     this->setLanguage(this->value("language", QString("en")).toString());
     this->setScreenOrientation(static_cast<ScreenOrientation::Orientation>(this->value("screenOrientation", ScreenOrientation::Orientation(ScreenOrientation::Automatic)).toInt()));
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    this->setFullscreen(this->value("fullscreen", false).toBool());
+#endif
     this->setMonitorClipboard(this->value("monitorClipboard", false).toBool());
     this->setNetworkProxyType(static_cast<NetworkProxyType::ProxyType>(this->value("networkProxyType", NetworkProxyType::ProxyType(NetworkProxyType::HttpProxy)).toInt()));
     this->setNetworkProxyHostName(this->value("networkProxyHostName", QString()).toString());
@@ -192,11 +205,14 @@ void Settings::saveSettings() {
     this->setValue("mediaPlayerCommand", this->mediaPlayerCommand());
 #endif
     this->setValue("languageFilter", this->languageFilter());
+    this->setValue("subtitlesLanguage", this->subtitlesLanguage());
     this->endGroup();
 
     this->beginGroup("Transfers");
     this->setValue("startTransfersAutomatically", this->startTransfersAutomatically());
     this->setValue("maximumConcurrentTransfers", this->maximumConcurrentTransfers());
+    this->setValue("maximumConnectionsPerTransfer", this->maximumConnectionsPerTransfer());
+    this->setValue("downloadSubtitles", this->downloadSubtitles());
     this->setValue("downloadPath", this->downloadPath());
     this->endGroup();
 
@@ -234,6 +250,9 @@ void Settings::saveSettings() {
     this->beginGroup("System");
     this->setValue("language", this->language());
     this->setValue("screenOrientation", ScreenOrientation::Orientation(this->screenOrientation()));
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    this->setValue("fullscreen", this->fullscreen());
+#endif
     this->setValue("monitorClipboard", this->monitorClipboard());
     this->setValue("networkProxyType", NetworkProxyType::ProxyType(this->networkProxyType()));
     this->setValue("networkProxyHostName", this->networkProxyHostName());
@@ -293,12 +312,13 @@ void Settings::setDailymotionPlaybackFormats(QVariantList formats) {
         m_dailymotionPlaybackFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_dailymotionPlaybackFormats.insert(Videos::Normal);
+    m_dailymotionPlaybackFormats.insert(Videos::LQ);
 
     emit dailymotionPlaybackFormatsChanged(m_dailymotionPlaybackFormats);
     emit enableDailymotion1080PlaybackChanged();
     emit enableDailymotion720PlaybackChanged();
     emit enableDailymotion480PlaybackChanged();
+    emit enableDailymotion384PlaybackChanged();
 }
 
 void Settings::setDailymotionDownloadFormats(QVariantList formats) {
@@ -306,12 +326,13 @@ void Settings::setDailymotionDownloadFormats(QVariantList formats) {
         m_dailymotionDownloadFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_dailymotionDownloadFormats.insert(Videos::Normal);
+    m_dailymotionDownloadFormats.insert(Videos::LQ);
 
     emit dailymotionDownloadFormatsChanged(m_dailymotionDownloadFormats);
     emit enableDailymotion1080DownloadChanged();
     emit enableDailymotion720DownloadChanged();
     emit enableDailymotion480DownloadChanged();
+    emit enableDailymotion384DownloadChanged();
 }
 
 void Settings::setVimeoPlaybackFormats(QVariantList formats) {
@@ -518,6 +539,18 @@ void Settings::setEnableDailymotion480Playback(bool enable) {
     emit enableDailymotion480PlaybackChanged();
 }
 
+void Settings::setEnableDailymotion384Playback(bool enable) {
+    if (enable) {
+        m_dailymotionPlaybackFormats.insert(Videos::Normal);
+    }
+    else {
+        m_dailymotionPlaybackFormats.remove(Videos::Normal);
+    }
+
+    emit dailymotionPlaybackFormatsChanged(m_dailymotionPlaybackFormats);
+    emit enableDailymotion384PlaybackChanged();
+}
+
 void Settings::setEnableDailymotion1080Download(bool enable) {
     if (enable) {
         m_dailymotionDownloadFormats.insert(Videos::SuperHD);
@@ -554,12 +587,24 @@ void Settings::setEnableDailymotion480Download(bool enable) {
     emit enableDailymotion480DownloadChanged();
 }
 
-void Settings::setEnableVimeo720Playback(bool enable) {
+void Settings::setEnableDailymotion384Download(bool enable) {
     if (enable) {
-        m_vimeoPlaybackFormats.insert(Videos::HQ);
+        m_dailymotionDownloadFormats.insert(Videos::Normal);
     }
     else {
-        m_vimeoPlaybackFormats.remove(Videos::HQ);
+        m_dailymotionDownloadFormats.remove(Videos::Normal);
+    }
+
+    emit dailymotionDownloadFormatsChanged(m_dailymotionDownloadFormats);
+    emit enableDailymotion384DownloadChanged();
+}
+
+void Settings::setEnableVimeo720Playback(bool enable) {
+    if (enable) {
+        m_vimeoPlaybackFormats.insert(Videos::HD);
+    }
+    else {
+        m_vimeoPlaybackFormats.remove(Videos::HD);
     }
 
     emit vimeoPlaybackFormatsChanged(m_vimeoPlaybackFormats);
@@ -613,12 +658,28 @@ void Settings::setStartTransfersAutomatically(bool automatic) {
 void Settings::setMaximumConcurrentTransfers(int maximum) {
     int oldMaximum = this->maximumConcurrentTransfers();
 
-    if ((maximum != oldMaximum) && (maximum > 0) && (maximum <= 3)) {
+    if ((maximum != oldMaximum) && (maximum > 0) && (maximum <= MAX_CONCURRENT_TRANSFERS)) {
         m_maxConcurrentTransfers = maximum;
         emit maximumConcurrentTransfersChanged(oldMaximum, maximum);
     }
 }
 
+void Settings::setMaximumConnectionsPerTransfer(int maximum) {
+    int oldMaximum = this->maximumConnectionsPerTransfer();
+
+    if ((maximum != oldMaximum) && (maximum > 0) && (maximum <= MAX_CONNECTIONS)) {
+        m_maxConnectionsPerTransfer = maximum;
+        emit maximumConnectionsPerTransferChanged(oldMaximum, maximum);
+    }
+}
+
+void Settings::setDownloadSubtitles(bool download) {
+    if (download != this->downloadSubtitles()) {
+        m_downloadSubtitles = download;
+        emit downloadSubtitlesChanged(download);
+    }
+}
+
 void Settings::setDownloadPath(const QString &path) {
     m_path = path;
 
@@ -728,6 +789,13 @@ void Settings::setShowSearchLanguage(bool show) {
     }
 }
 
+void Settings::setSubtitlesLanguage(const QString &language) {
+    if (language != this->subtitlesLanguage()) {
+        m_subtitlesLanguage = language;
+        emit subtitlesLanguageChanged(language);
+    }
+}
+
 #if (defined (SYMBIAN_OS)) || (defined (MEEGO_EDITION_HARMATTAN))
 void Settings::setTheme(const QString &theme) {
     if (theme != this->theme()) {
@@ -799,6 +867,15 @@ void Settings::setScreenOrientation(ScreenOrientation::Orientation orientation)
     }
 }
 
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+void Settings::setFullscreen(bool fullscreen) {
+    if (fullscreen != this->fullscreen()) {
+        m_fullscreen = fullscreen;
+        emit fullscreenChanged(fullscreen);
+    }
+}
+#endif
+
 void Settings::setMonitorClipboard(bool monitor) {
     if (monitor != this->monitorClipboard()) {
         m_monitorClipboard = monitor;
@@ -807,16 +884,7 @@ void Settings::setMonitorClipboard(bool monitor) {
 }
 
 QString Settings::networkProxyTypeString() const {
-    switch (this->networkProxyType()) {
-    case NetworkProxyType::Socks5Proxy:
-        return QString("SOCKS5");
-    case NetworkProxyType::HttpProxy:
-        return QString("HTTP");
-    case NetworkProxyType::HttpCachingProxy:
-        return QString("HTTP %1").arg(tr("caching"));
-    default:
-        return QString("HTTP");
-    }
+    return NetworkProxyType::networkProxyTypeString(this->networkProxyType());
 }
 
 void Settings::setNetworkProxyType(NetworkProxyType::ProxyType proxyType) {
