@@ -1112,8 +1112,16 @@ void TransferItem::onConnectionCompleted(Connection *connection) {
         connection->deleteLater();
 
         if (m_connections.isEmpty()) {
-            if (this->size() <= 0) {
-                this->onFileWriteCompleted();
+            switch (this->transferType()) {
+            case Transfers::Upload:
+                this->setStatus(Transfers::Completed);
+                return;
+            default:
+                if (this->size() <= 0) {
+                    this->onFileWriteCompleted();
+                }
+
+                return;
             }
         }
         else if ((this->activeConnections() < this->preferredConnections()) && ((this->size() - this->position()) > MIN_FRAGMENT_SIZE)) {
