@@ -1,6 +1,7 @@
 #include "urlgrabber.h"
 #include "cookiejar.h"
 #include "json.h"
+#include "definitions.h"
 #include "utils.h"
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
@@ -8,6 +9,8 @@
 #include <QStringList>
 #include <QRegExp>
 #include <QScriptEngine>
+#include <QDomDocument>
+#include <QDomElement>
 #include <QDebug>
 #if QT_VERSION >= 0x050000
 #include <QUrlQuery>
@@ -15,25 +18,29 @@
 
 using namespace QtJson;
 
-UrlGrabber* grabberInstance = 0;
-QScriptEngine* youtubeDecryptionEngine = 0;
-QHash<QUrl, QScriptValue> youtubeDecryptionCache;
+UrlGrabber* UrlGrabber::self = 0;
+QScriptEngine* UrlGrabber::youtubeDecryptionEngine = 0;
+QHash<QUrl, QScriptValue> UrlGrabber::youtubeDecryptionCache;
 
 UrlGrabber::UrlGrabber(QObject *parent) :
     QObject(parent),
     m_nam(0),
     m_format(Videos::Unknown),
+    m_language("en"),
     m_busy(false),
     m_cancelled(false)
 {
-    if (!grabberInstance) {
-        grabberInstance = this;
-        youtubeDecryptionEngine = new QScriptEngine(this);
+    if (!self) {
+        self = this;
+    }
+
+    if (!youtubeDecryptionEngine) {
+        youtubeDecryptionEngine = new QScriptEngine;
     }
 }
 
 UrlGrabber* UrlGrabber::instance() {
-    return grabberInstance;
+    return !self ? new UrlGrabber : self;
 }
 
 void UrlGrabber::setYouTubeFormats(QSet<int> formats) {
@@ -98,9 +105,12 @@ void UrlGrabber::setDailymotionFormats(QSet<int> formats) {
         case Videos::MobileLQ:
         case Videos::MobileNormal:
         case Videos::LQ:
+            videoFormat.value = "stream_h264_ld_url";
+            videoFormat.displayName = "240P AVC1";
+            break;
         case Videos::Normal:
             videoFormat.value = "stream_h264_url";
-            videoFormat.displayName = QString("%1 AVC1").arg(tr("Normal"));
+            videoFormat.displayName = "384P AVC1";
             break;
         case Videos::HQ:
             videoFormat.value = "stream_h264_hq_url";
@@ -204,7 +214,7 @@ QScriptValue UrlGrabber::getYouTubeDecryptionFunction(const QUrl &playerUrl) {
     }
 
     QNetworkRequest request(playerUrl);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addYouTubeDecryptionFunctionToCache()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -356,7 +366,7 @@ void UrlGrabber::getYouTubeVideoInfoPage(const QString &id, const char *slot) {
     url.addQueryItem("hl", "en");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -423,7 +433,7 @@ void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
     url.addQueryItem("has_verified", "1");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -840,13 +850,15 @@ void UrlGrabber::checkDailymotionVideoFormats() {
     keys << "stream_h264_hd1080_url"
          << "stream_h264_hd_url"
          << "stream_h264_hq_url"
-         << "stream_h264_url";
+         << "stream_h264_url"
+         << "stream_h264_ld_url";
 
     QStringList names;
     names << "1080P AVC1"
-          << "720 AVC1"
+          << "720P AVC1"
           << "480P AVC1"
-          << QString("%1 AVC1").arg(tr("Normal"));
+          << "348P AVC1"
+          << "240P AVC1";
 
     for (int i = 0; i < keys.size(); i++){
         QUrl url = info.value(keys.at(i)).toUrl();
@@ -931,3 +943,332 @@ void UrlGrabber::checkVimeoVideoFormats() {
 
     reply->deleteLater();
 }
+
+void UrlGrabber::getSubtitlesUrl(int service, const QString &id, const QString &language) {
+    switch (service) {
+    case Services::YouTube:
+        this->getYouTubeSubtitlesUrl(id, language);
+        return;
+    case Services::Dailymotion:
+        this->getDailymotionSubtitlesUrl(id, language);
+        return;
+    case Services::Vimeo:
+        this->getVimeoSubtitlesUrl(id, language);
+        return;
+    default:
+        qWarning() << "UrlGrabber::getSubtitlesUrl(): No/invalid service specied";
+        return;
+    }
+}
+
+void UrlGrabber::getYouTubeSubtitlesUrl(const QString &id, const QString &language) {
+    this->setBusy(true, tr("Loading subtitles"));
+    m_language = language;
+    QUrl url("https://video.google.com/timedtext?hl=en&type=list&v=" + id);
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkYouTubeSubtitles()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkYouTubeSubtitles() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QDomDocument doc;
+    doc.setContent(reply->readAll());
+    QDomElement transcriptEl = doc.documentElement();
+    QDomNodeList trackNodes = transcriptEl.elementsByTagName("track");
+
+    int i = 0;
+    bool found = false;
+
+    while ((!found) && (i < trackNodes.size())) {
+        QDomElement trackEl = trackNodes.at(i).toElement();
+
+        if (trackEl.attribute("lang_code") == m_language) {
+            found = true;
+        }
+
+        i++;
+    }
+
+    if (found) {
+        QUrl url("https://www.youtube.com/api/timedtext?fmt=srt");
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("v", QUrlQuery(reply->request().url()).queryItemValue("v"));
+        query.addQueryItem("lang", m_language);
+#else
+        url.addQueryItem("v", reply->request().url().queryItemValue("v"));
+        url.addQueryItem("lang", m_language);
+#endif
+        emit gotSubtitlesUrl(url);
+    }
+    else {
+        emit error(tr("No subtitles found"));
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::getDailymotionSubtitlesUrl(const QString &id, const QString &language) {
+    this->setBusy(true, tr("Loading subtitles"));
+    m_language = language;
+    QUrl url(QString("https://api.dailymotion.com/video/%1/subtitles?fields=id,language,url").arg(id));
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkDailymotionSubtitles()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkDailymotionSubtitles() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QString response(reply->readAll());
+    QVariantList list = Json::parse(response).toMap().value("list").toList();
+
+    int i = 0;
+    QUrl url;
+
+    while ((url.isEmpty()) && (i < list.size())) {
+        QVariantMap map = list.at(i).toMap();
+
+        if (map.value("language") == m_language) {
+            url = map.value("url").toUrl();
+        }
+
+        i++;
+    }
+
+    if (!url.isEmpty()) {
+        emit gotSubtitlesUrl(url);
+    }
+    else {
+        emit error(tr("No subtitles found"));
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::getVimeoSubtitlesUrl(const QString &id, const QString &language) {
+    this->setBusy(true, tr("Loading subtitles"));
+    m_language = language;
+    QUrl url("http://player.vimeo.com/video/" + id);
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkVimeoSubtitles()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkVimeoSubtitles() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QString response(reply->readAll());
+    QString params = response.section("\"text_tracks\":", 1, 1).section(",\"cookie_domain\":", 0, 0);
+    QVariantList list = Json::parse(params).toList();
+
+    int i = 0;
+    QUrl url;
+
+    while ((url.isEmpty()) && (i < list.size())) {
+        QVariantMap map = list.at(i).toMap();
+
+        if (map.value("lang") == m_language) {
+            url = QUrl::fromEncoded(map.value("url").toString().section("url=", -1).toUtf8());
+        }
+
+        i++;
+    }
+
+    if (!url.isEmpty()) {
+        emit gotSubtitlesUrl(url);
+    }
+    else {
+        emit error(tr("No subtitles found"));
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::getAvailableSubtitles(int service, const QString &id) {
+    switch (service) {
+    case Services::YouTube:
+        this->getAvailableYouTubeSubtitles(id);
+        return;
+    case Services::Dailymotion:
+        this->getAvailableDailymotionSubtitles(id);
+        return;
+    case Services::Vimeo:
+        this->getAvailableVimeoSubtitles(id);
+        return;
+    default:
+        qWarning() << "UrlGrabber::getAvailableSubtitles(): No/invalid service specied";
+        return;
+    }
+}
+
+void UrlGrabber::getAvailableYouTubeSubtitles(const QString &id) {
+    this->setBusy(true, tr("Retrieving available subtitles"));
+    QUrl url("https://video.google.com/timedtext?hl=en&type=list&v=" + id);
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkAvailableYouTubeSubtitles()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkAvailableYouTubeSubtitles() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QDomDocument doc;
+    doc.setContent(reply->readAll());
+    QDomElement transcriptEl = doc.documentElement();
+    QDomNodeList trackNodes = transcriptEl.elementsByTagName("track");
+    QVariantList list;
+
+    for (int i = 0; i < trackNodes.size(); i++) {
+        QDomElement trackEl = trackNodes.at(i).toElement();
+        QString language = trackEl.attribute("lang_code");
+        QUrl url("https://www.youtube.com/api/timedtext?fmt=srt");
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("v", QUrlQuery(reply->request().url()).queryItemValue("v"));
+        query.addQueryItem("lang", m_language);
+#else
+        url.addQueryItem("v", reply->request().url().queryItemValue("v"));
+        url.addQueryItem("lang", m_language);
+#endif
+        QVariantMap map;
+        map["language"] = language;
+        map["url"] = url;
+
+        list << map;
+    }
+
+    if (list.isEmpty()) {
+        emit error(tr("No subtitles found"));
+    }
+    else {
+        emit gotSubtitles(list);
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::getAvailableDailymotionSubtitles(const QString &id) {
+    this->setBusy(true, tr("Retrieving available subtitles"));
+    QUrl url(QString("https://api.dailymotion.com/video/%1/subtitles?fields=id,language,url").arg(id));
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkDailymotionSubtitles()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkAvailableDailymotionSubtitles() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QString response(reply->readAll());
+    QVariantList list = Json::parse(response).toMap().value("list").toList();
+
+    if (list.isEmpty()) {
+        emit error(tr("No subtitles found"));
+    }
+    else {
+        emit gotSubtitles(list);
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::getAvailableVimeoSubtitles(const QString &id) {
+    this->setBusy(true, tr("Retrieving available subtitles"));
+    QUrl url("http://player.vimeo.com/video/" + id);
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkAvailableVimeoSubtitles()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkAvailableVimeoSubtitles() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QString response(reply->readAll());
+    QString params = response.section("\"text_tracks\":", 1, 1).section(",\"cookie_domain\":", 0, 0);
+    QVariantList list = Json::parse(params).toList();
+    QVariantList subtitles;
+
+    if (list.isEmpty()) {
+        emit error(tr("No subtitles found"));
+    }
+    else {
+        foreach (QVariant variant, list) {
+            QVariantMap map = variant.toMap();
+            map["language"] = map.value("lang").toString();
+            map["url"] = QUrl::fromEncoded(map.value("url").toString().section("url=", -1).toUtf8());
+            subtitles << map;
+        }
+
+        emit gotSubtitles(subtitles);
+    }
+
+    reply->deleteLater();
+}
