@@ -79,13 +79,13 @@ QString Utils::dateFromMSecs(qint64 msecs, bool showTime) {
 }
 
 QString Utils::toRichText(QString s) {
-    QRegExp re("((http(s|)://|[^\\s<\"']+@)[^\\s<\"']+)");
+    QRegExp re("((http(s|)://|[\\w-_\\.]+@)[^\\s<:\"']+)");
     int pos = 0;
 
     while ((pos = re.indexIn(s, pos)) != -1) {
         QString link = re.cap(1);
         s.replace(pos, link.size(), QString("<a href='%1'>%2</a>").arg(link.contains('@') ? "mailto:" + link : link).arg(link));
-        pos += re.matchedLength() * 2 + 15;        
+        pos += re.matchedLength() * 2 + 15;
     }
 
     return s.replace("\n", "<br>");
