@@ -23,6 +23,9 @@ public:
 public:
     explicit YouTubeAccountsListModel(QObject *parent = 0);
     ~YouTubeAccountsListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     QVariant data(const QModelIndex &idx, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
 
@@ -41,6 +44,9 @@ signals:
     void info(const QString &message);
     void error(const QString &errorString);
     void countChanged(int count);
+
+private:
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // YOUTUBEACCOUNTSLISTMODEL_H
