@@ -4,6 +4,9 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 YouTubeCommentListModel::YouTubeCommentListModel(QObject *parent) :
     AbstractCommentListModel(parent),
@@ -35,7 +38,7 @@ void YouTubeCommentListModel::reset() {
 void YouTubeCommentListModel::setVideoId(const QString &id) {
     if (id != this->videoId()) {
         m_videoId = id;
-        this->setFeed(QUrl(QString("%1/%2/comments?v=2.1&max-results=30").arg(YOUTUBE_VIDEOS_BASE_URL).arg(id)));
+        this->setFeed(QUrl(QString("%1/%2/comments?v=2.1&orderby=published&max-results=30").arg(YOUTUBE_VIDEOS_BASE_URL).arg(id)));
     }
 }
 
@@ -46,7 +49,13 @@ void YouTubeCommentListModel::getComments(const QString &id) {
 
     this->setLoading(true);
     QUrl feed = this->feed();
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("fields", YOUTUBE_COMMENT_FIELDS);
+    feed.setQuery(query);
+#else
     feed.addQueryItem("fields", YOUTUBE_COMMENT_FIELDS);
+#endif
     QNetworkReply *reply = YouTube::instance()->createReply(feed, this->offset());
     reply->setParent(this);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addComments()));
