@@ -1,5 +1,5 @@
 #include "aboutdialog.h"
-#include "../base/utils.h"
+#include "../base/definitions.h"
 #include <QLabel>
 #include <QPushButton>
 #include <QDialogButtonBox>
@@ -11,7 +11,7 @@
 AboutDialog::AboutDialog(QWidget *parent) :
     AbstractDialog(parent),
     m_icon(new QLabel(this)),
-    m_title(new QLabel("cuteTube " + Utils::versionNumberString(), this)),
+    m_title(new QLabel("cuteTube " + VERSION_NUMBER, this)),
     m_details(new QLabel(tr("A fully-featured client for YouTube, Dailymotion and Vimeo.") + "<br><br> &copy; Stuart Howarth 2010-2014", this)),
     m_buttonBox(new QDialogButtonBox(Qt::Vertical, this)),
     m_donateButton(m_buttonBox->addButton(tr("Donate"), QDialogButtonBox::ActionRole)),
@@ -72,6 +72,6 @@ void AboutDialog::donate() {
 }
 
 void AboutDialog::reportBug() {
-    QDesktopServices::openUrl(QUrl(QString("mailto:showarth@marxoft.co.uk?subject=cuteTube %1 for N900").arg(Utils::versionNumberString())));
+    QDesktopServices::openUrl(QUrl(QString("mailto:showarth@marxoft.co.uk?subject=cuteTube %1 for N900").arg(VERSION_NUMBER)));
     this->close();
 }
