@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include "../base/videoitem.h"
 
-class Session;
 class DailymotionUploadCategorySelector;
 class QLineEdit;
 class QTextEdit;
@@ -19,7 +18,7 @@ class DailymotionMetadataDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit DailymotionMetadataDialog(Session *session, QSharedPointer<VideoItem> video, QWidget *parent = 0);
+    explicit DailymotionMetadataDialog(QSharedPointer<VideoItem> video, QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -31,7 +30,6 @@ private slots:
     void submitMetadata();
 
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     QLineEdit *m_titleEdit;
     QTextEdit *m_descriptionEdit;
