@@ -4,7 +4,6 @@
 #include "stackedwindow.h"
 #include "../base/videoitem.h"
 
-class Session;
 class DailymotionVideoDescriptionTab;
 class DailymotionVideoCommentsTab;
 class DailymotionRelatedVideosTab;
@@ -16,7 +15,7 @@ class DailymotionVideoInfoWindow : public StackedWindow
 {
     Q_OBJECT
 public:
-    explicit DailymotionVideoInfoWindow(Session *session, QSharedPointer<VideoItem> video, QWidget *parent);
+    explicit DailymotionVideoInfoWindow(QSharedPointer<VideoItem> video, QWidget *parent);
 
 private:
     void clearMenuActions();
