@@ -1,7 +1,8 @@
 #include "homewindow.h"
 #include "dbusadaptor.h"
-#include "transferitem.h"
-#include "../base/utils.h"
+#include "../base/transferitem.h"
+#include "resourceloader.h"
+#include "../base/definitions.h"
 #include "../base/session.h"
 #include "../base/settings.h"
 #include "../base/commentitem.h"
@@ -15,7 +16,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setApplicationName("cuteTube");
-    app.setApplicationVersion(Utils::versionNumberString());
+    app.setApplicationVersion(VERSION_NUMBER);
 
     qRegisterMetaType< QSharedPointer<CommentItem> >("QSharedPointer<CommentItem>");
     qRegisterMetaType< QSharedPointer<GroupItem> >("QSharedPointer<GroupItem>");
@@ -26,6 +27,12 @@ int main(int argc, char *argv[])
 
     new Session;
 
+    ResourceLoader loader;
+    new DBusAdaptor(&loader);
+    QDBusConnection connection = QDBusConnection::sessionBus();
+    connection.registerService("com.maemo.cuteTube");
+    connection.registerObject("/", &loader);
+
     if (!Settings::instance()->language().isEmpty()) {
         QTranslator translator;
         translator.load(QString("/opt/cutetube/translations/cutetube_%1").arg(Settings::instance()->language()));
@@ -33,11 +40,6 @@ int main(int argc, char *argv[])
     }
 
     HomeWindow window;
-    new DBusAdaptor(&window);
-    QDBusConnection connection = QDBusConnection::sessionBus();
-    connection.registerService("com.maemo.cuteTube");
-    connection.registerObject("/", &window);
-
     window.show();
 
     QObject::connect(&app, SIGNAL(aboutToQuit()), Session::instance(), SLOT(deleteLater()));
