@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include "../base/videoitem.h"
 
-class Session;
 class QTextEdit;
 class QPushButton;
 class QDialogButtonBox;
@@ -15,8 +14,9 @@ class QLabel;
 class ShareToTwitterDialog : public AbstractDialog
 {
     Q_OBJECT
+
 public:
-    explicit ShareToTwitterDialog(Session *session, QSharedPointer<VideoItem> video, QWidget *parent = 0);
+    explicit ShareToTwitterDialog(QSharedPointer<VideoItem> video, QWidget *parent = 0);
     
 private:
     void setLandscapeLayout();
@@ -27,7 +27,6 @@ private slots:
     void shareVideo();
 
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     QTextEdit *m_messageEdit;
     QLabel *m_charCountLabel;
