@@ -4,7 +4,6 @@
 #include "stackedwindow.h"
 #include "../base/videoitem.h"
 
-class Session;
 class SocialVideoListModel;
 class ListView;
 class QAction;
@@ -14,8 +13,9 @@ class QModelIndex;
 class SocialVideoListWindow : public StackedWindow
 {
     Q_OBJECT
+
 public:
-    explicit SocialVideoListWindow(Session *session, QWidget *parent);
+    explicit SocialVideoListWindow(QWidget *parent);
 
 private:
     void setLandscapeLayout();
