@@ -26,6 +26,7 @@ protected:
     void mouseReleaseEvent(QMouseEvent *event);
     void leaveEvent(QEvent *event);
     void paintEvent(QPaintEvent *event);
+    void timerEvent(QTimerEvent *event);
 
 signals:
     void clicked();
@@ -35,6 +36,7 @@ private:
     int m_duration;
     bool m_interactive;
     bool m_pressed;
+    bool m_allowClick;
 };
 
 #endif // THUMBNAILLABEL_H
