@@ -11,6 +11,9 @@ class VideoWidget : public QVideoWidget
 public:
     explicit VideoWidget(QWidget *parent = 0);
 
+public slots:
+    void toggleAspectRatioMode();
+
 protected:
     void mousePressEvent(QMouseEvent *event);
     void mouseReleaseEvent(QMouseEvent *event);
