@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include <QUrl>
 
-class Session;
 class WebView;
 class QProgressBar;
 class QGridLayout;
@@ -14,7 +13,7 @@ class VimeoAuthDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit VimeoAuthDialog(Session *session, const QString &accountName, QWidget *parent = 0);
+    explicit VimeoAuthDialog(const QString &accountName, QWidget *parent = 0);
 
 private:
     inline void setLandscapeLayout() { this->setFixedHeight(340); }
@@ -25,7 +24,6 @@ private slots:
     void checkUrlForToken(const QUrl &url);
 
 private:
-    Session *m_session;
     QString m_name;
     QUrl m_authUrl;
     WebView *m_webView;
