@@ -15,12 +15,15 @@
 #include "../base/vimeo.h"
 #include "../base/sharing.h"
 #include "../base/videoitem.h"
+#include "../base/utils.h"
 #include "thumbnaillabel.h"
 #include "ratingindicator.h"
+#include "resourceloader.h"
 #include <QAction>
 #include <QLabel>
 #include <QScrollArea>
 #include <QGridLayout>
+#include <QDesktopServices>
 #include <QMaemo5Style>
 
 VimeoVideoDescriptionTab::VimeoVideoDescriptionTab(QSharedPointer<VideoItem> video, QWidget *parent) :
@@ -38,7 +41,7 @@ VimeoVideoDescriptionTab::VimeoVideoDescriptionTab(QSharedPointer<VideoItem> vid
     m_dateLabel(new QLabel(QString("%1 - %2").arg(m_video.data()->date()).arg(m_video.data()->artist()), this)),
     m_likesLabel(new QLabel(QString("%1   <font color='%2'>%3</font>").arg(tr("Likes")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->likes()), this)),
     m_viewsLabel(new QLabel(QString("%1   <font color='%2'>%3</font>").arg(tr("Views")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->viewCount()), this)),
-    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : m_video.data()->description()), this)),
+    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : Utils::toRichText(m_video.data()->description())), this)),
     m_tagsLabel(new QLabel(this->tagsToString(m_video.data()->tags()), this)),
     m_scrollArea(new QScrollArea(this)),
     m_grid(new QGridLayout(this))
@@ -85,6 +88,7 @@ VimeoVideoDescriptionTab::VimeoVideoDescriptionTab(QSharedPointer<VideoItem> vid
     this->connect(m_videoDownloadAction, SIGNAL(triggered()), this, SLOT(addVideoDownload()));
     this->connect(m_audioDownloadAction, SIGNAL(triggered()), this, SLOT(addAudioDownload()));
     this->connect(m_shareAction, SIGNAL(triggered()), this, SLOT(showShareDialog()));
+    this->connect(m_descriptionLabel, SIGNAL(linkActivated(QString)), this, SLOT(parseActivatedLink(QString)));
     this->connect(m_tagsLabel, SIGNAL(linkActivated(QString)), this, SLOT(search(QString)));
     this->connect(m_video.data(), SIGNAL(favouriteChanged(bool)), this, SLOT(onLikeChanged(bool)));
     this->connect(m_video.data(), SIGNAL(likesChanged(int)), this, SLOT(onLikesChanged(int)));
@@ -257,6 +261,12 @@ void VimeoVideoDescriptionTab::showUserChannel() {
     window->show();
 }
 
+void VimeoVideoDescriptionTab::parseActivatedLink(const QString &link) {
+    if (!ResourceLoader::instance()->display(link, false)) {
+        QDesktopServices::openUrl(link);
+    }
+}
+
 void VimeoVideoDescriptionTab::search(const QString &query) {
     VimeoVideoListWindow *window = new VimeoVideoListWindow(WindowStack::instance()->currentWindow());
     window->search(query, Settings::instance()->searchOrder());
