@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/playlistitem.h"
 
-class Session;
 class ListView;
 class YouTubeUserPlaylistListModel;
 class QLabel;
@@ -16,8 +15,9 @@ class QModelIndex;
 class YouTubeUserPlaylistListTab : public AbstractTab
 {
     Q_OBJECT
+
 public:
-    explicit YouTubeUserPlaylistListTab(Session *session, QWidget *parent = 0);
+    explicit YouTubeUserPlaylistListTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -33,7 +33,6 @@ private slots:
     void showNewPlaylistDialog();
 
 private:
-    Session *m_session;
     ListView *m_listView;
     YouTubeUserPlaylistListModel *m_model;
     QMenu *m_contextMenu;
