@@ -1,6 +1,6 @@
 #include "dailymotion.h"
 #include "../../cutetubeapp/src/base/json.h"
-#include "../../cutetubeapp/src/base/utils.h"
+#include "../../cutetubeapp/src/base/definitions.h"
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QDebug>
@@ -50,7 +50,7 @@ QNetworkReply* Dailymotion::createReply(QString feed, int offset) {
     qDebug() << url;
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
 
     return this->networkAccessManager()->get(request);
 }
@@ -77,7 +77,7 @@ void Dailymotion::refreshAccessToken() {
                     "&grant_type=refresh_token");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkTokenRefresh()));
