@@ -19,7 +19,7 @@
 #include <QDir>
 #include <QDateTime>
 #include <QSettings>
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
 #include <QNetworkConfigurationManager>
 #include <QNetworkSession>
 #ifdef MEEGO_EDITION_HARMATTAN
@@ -81,7 +81,7 @@ void Events::init() {
 
 bool Events::enableSync() {
     QSettings settings("cuteTube", "cuteTube");
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
     settings.setValue("Events/eventFeedEnabled", true);
     bool success = true;
 #else
@@ -104,7 +104,7 @@ bool Events::enableSync() {
 
 bool Events::disableSync() {
     QSettings settings("cuteTube", "cuteTube");
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
     settings.remove("Events/youtubeLatest");
     settings.remove("Events/dailymotionLatest");
     settings.remove("Events/vimeoLatest");
@@ -169,7 +169,7 @@ void Events::getEvents() {
 }
 
 void Events::getYouTubeEvents() {
-    QDateTime youtubeLatest = QDateTime::fromMSecsSinceEpoch(QSettings("cuteTube", "cuteTube").value("Events/youtubeLatest", 0).toLongLong());
+    QDateTime youtubeLatest = QSettings("cuteTube", "cuteTube").value("Events/youtubeLatest", QDate(1970, 1, 1)).toDateTime();
     QNetworkReply *reply = m_youtube->createReply(QString("https://gdata.youtube.com/feeds/api/users/default/newsubscriptionvideos?v=2.1&max-results=50&fields=openSearch:totalResults,entry[xs:dateTime(published) > xs:dateTime('%1')](id,media:group(media:title,media:thumbnail[@yt:name='default'or@yt:name='hqdefault'],media:description,media:player[@url],media:credit,yt:uploaded,yt:uploaderId,yt:videoid))").arg(youtubeLatest.toString(Qt::ISODate)));
     this->connect(reply, SIGNAL(finished()), this, SLOT(processYouTubeEvents()));
 }
@@ -205,19 +205,15 @@ void Events::processYouTubeEvents() {
             event.setBody(mediaGroup.firstChildElement("media:description").text());
             event.setImagePathOne(mediaGroup.firstChildElement("media:thumbnail").attribute("url").section('/', 0, -2).append("/mqdefault.jpg"));
             event.setFooter(mediaGroup.firstChildElement("media:credit").attribute("yt:display"));
-#ifdef MEEGO_EDITION_HARMATTAN
-            event.setTimestamp(QDateTime::fromString(mediaGroup.firstChildElement("yt:uploaded").text(), Qt::ISODate).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
-            event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant(event.url()))));
-#elif defined (Q_WS_SAILFISH)
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
             event.setTimestamp(QDateTime::fromString(mediaGroup.firstChildElement("yt:uploaded").text(), Qt::ISODate).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
 #else
             event.setTimestamp(mediaGroup.firstChildElement("yt:uploaded").text());
-            event.setAction("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display http://youtu.be/" + event.id());
 #endif
             m_events.append(event);
 
             if (i == 0) {
-                QSettings("cuteTube", "cuteTube").setValue("Events/youtubeLatest", QDateTime::fromString(event.timestamp(), Qt::ISODate).toMSecsSinceEpoch());
+                QSettings("cuteTube", "cuteTube").setValue("Events/youtubeLatest", QDateTime::fromString(mediaGroup.firstChildElement("yt:uploaded").text(), Qt::ISODate));
             }
         }
 
@@ -225,7 +221,7 @@ void Events::processYouTubeEvents() {
             this->getDailymotionEvents();
         }
         else {
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
             this->downloadThumbnails();
 #else
             this->addEvents();
@@ -264,12 +260,12 @@ void Events::processDailymotionEvents() {
             return;
         }
 
-        qint64 dailymotionLatest = QSettings("cuteTube", "cuteTube").value("Events/dailymotionLatest", 0).toLongLong();
+        QDateTime dailymotionLatest = QSettings("cuteTube", "cuteTube").value("Events/dailymotionLatest", QDate(1970, 1, 1)).toDateTime();
         QVariantList entries = res.value("list").toList();
 
         for (int i = 0; i < entries.size(); i++) {
             QVariantMap entry = entries.at(i).toMap();
-            qint64 date = entry.value("created_time").toLongLong() * 1000;
+            QDateTime date = QDateTime::fromMSecsSinceEpoch(entry.value("created_time").toLongLong() * 1000);
 
             if (date > dailymotionLatest) {
                 Event event;
@@ -282,28 +278,24 @@ void Events::processDailymotionEvents() {
                 event.setBody(entry.value("description").toString());
                 event.setImagePathOne(entry.value("thumbnail_large_url").toString());
                 event.setFooter(entry.value("owner.username").toString());
-#ifdef MEEGO_EDITION_HARMATTAN
-                event.setTimestamp(QDateTime::fromMSecsSinceEpoch(date).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
-                event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant(event.url()))));
-#elif defined (Q_WS_SAILFISH)
-                event.setTimestamp(QDateTime::fromMSecsSinceEpoch(date).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
+                event.setTimestamp(date.toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
 #else
-                event.setTimestamp(QString::number(date));
-                event.setAction("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display http://dai.ly/" + event.id());
+                event.setTimestamp(date.toLocalTime().toString(Qt::ISODate));
 #endif
                 m_events.append(event);
+
+                if (i == 0) {
+                    QSettings("cuteTube", "cuteTube").setValue("Events/dailymotionLatest", date);
+                }
             }
         }
-        
-        if (!entries.isEmpty()) {
-            QSettings("cuteTube", "cuteTube").setValue("Events/dailymotionLatest", entries.first().toMap().value("created_time").toLongLong() * 1000);
-        }
 
         if (m_vimeo->userSignedIn()) {
             this->getVimeoEvents();
         }
         else {
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
             this->downloadThumbnails();
 #else
             this->addEvents();
@@ -332,7 +324,7 @@ void Events::processVimeoEvents() {
     QDomElement responseNode = doc.firstChildElement("rsp");
 
     if (responseNode.attribute("stat") == "ok") {
-        QDateTime vimeoLatest = QDateTime::fromMSecsSinceEpoch(QSettings("cuteTube", "cuteTube").value("Events/vimeoLatest", 0).toLongLong());
+        QDateTime vimeoLatest = QSettings("cuteTube", "cuteTube").value("Events/vimeoLatest", QDate(1970, 1, 1)).toDateTime();
         QDomNodeList entries = doc.elementsByTagName("video");
 
         for (int i = 0; i < entries.size(); i++) {
@@ -356,23 +348,19 @@ void Events::processVimeoEvents() {
                     event.setImagePathOne(thumbnails.at(2).toElement().text());
                 }
 
-#ifdef MEEGO_EDITION_HARMATTAN
-                event.setTimestamp(date.toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
-                event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant(event.url()))));
-#elif defined (Q_WS_SAILFISH)
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
                 event.setTimestamp(date.toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
 #else
-                event.setTimestamp(QString::number(date.toMSecsSinceEpoch()));
-                event.setAction("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display http://vimeo.com/" + event.id());
+                event.setTimestamp(date.toLocalTime().toString(Qt::ISODate));
 #endif
                 m_events.append(event);
+
+                if (i == 0) {
+                    QSettings("cuteTube", "cuteTube").setValue("Events/vimeoLatest", date);
+                }
             }
         }
-
-        if (!entries.isEmpty()) {
-            QSettings("cuteTube", "cuteTube").setValue("Events/vimeoLatest", QDateTime::currentMSecsSinceEpoch());
-        }
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
         this->downloadThumbnails();
 #else
         this->addEvents();
@@ -386,13 +374,12 @@ void Events::processVimeoEvents() {
 }
 
 void Events::addEvents() {
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
     while (!m_events.isEmpty()) {
         QVariantList args;
         QVariantMap itemArgs;
         Event event = m_events.takeFirst();
         itemArgs.insert("title", event.title());
-        itemArgs.insert("url", event.url());
         itemArgs.insert("icon", event.iconPath());
         itemArgs.insert("body", event.body());
         itemArgs.insert("imageList", QStringList(event.imagePathOne()));
@@ -401,7 +388,11 @@ void Events::addEvents() {
         itemArgs.insert("footer", event.footer());
         itemArgs.insert("sourceName", QString("cutetube"));
         itemArgs.insert("sourceDisplayName", QString("cuteTube"));
-        itemArgs.insert("action", event.action());
+#ifdef MEEGO_EDITION_HARMATTAN
+        itemArgs.insert("action", "com.maemo.cuteTube / com.maemo.cuteTube display " + this->base64SerializedVariant(event.url()));
+#else
+        itemArgs.insert("url", event.url());
+#endif
         args.append(itemArgs);
 
 #ifdef MEEGO_EDITION_HARMATTAN
@@ -422,7 +413,7 @@ void Events::addEvents() {
         args.append(QStringList(event.imagePathOne()));
         args.append(event.footer());
         args.append(event.timestamp());
-        args.append(event.action());
+        args.append("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display " + event.url());
 
         QDBusInterface("com.maemo.eventFeed", "/", "com.maemo.eventFeed").callWithArgumentList(QDBus::Block, "addEvent", args);
     }
@@ -430,7 +421,7 @@ void Events::addEvents() {
     this->syncSuccess();
 }
 
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
 QString Events::base64SerializedVariant(const QVariant &value) const
 {
     QByteArray ba;
